package com.caimei.module.pay.service;

import com.caimei.module.base.entity.bo.JsonModel;
import com.caimei.module.base.entity.bo.Payment;
import com.caimei.module.base.entity.vo.OrderPayLinkVo;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.io.IOException;

/**
 * Description
 *
 * @author : plf
 * @date : 2020/5/9
 */
public interface PayService {
    /**
     * 获取线上支付开关状态
     *
     * @return
     */
    JsonModel getPayOnLineSwitch();

    /**
     * 收银台数据
     *
     * @param orderId 订单id
     * @return
     */
    JsonModel checkoutCounter(Integer orderId);

    /**
     * 线上支付
     *
     * @param payment 支付参数对象
     * @param request
     * @return
     */
    JsonModel pay(Payment payment, HttpServletRequest request);

    /**
     * 异步回调通知
     */
    String paymentCallback(String data) throws Exception;

    /**
     * 小程序生成链接
     */
    JsonModel payLink(OrderPayLinkVo orderPayLink);

    /**
     * 重定向到收银台页面
     */
    void jumpPage(String linkLogo, String linkPage, HttpServletResponse response) throws IOException;

    /**
     * 链接数据
     *
     * @param linkLogo
     * @return
     */
    JsonModel linkData(String linkLogo);

    /**
     * 判断此次支付是否完成
     *
     * @param orderId           订单id
     * @param paySuccessCounter 付款次数
     * @return
     */
    JsonModel payWhetherSuccess(Integer orderId, Integer paySuccessCounter);

    /**
     * 查询第三方订单状态
     *
     * @param mbOrderId 平台唯一流水号
     * @return
     */
    JsonModel findOrderStatus(String mbOrderId);

    /**
     * 二手交易发布信息,银联,支付宝,微信
     *
     * @param payment 支付信息
     * @param request
     * @return
     */
    JsonModel secondHandPay(Payment payment, HttpServletRequest request);

    /**
     * 二手支付异步通知回调
     *
     * @param data 回调参数
     * @return
     */
    String secondHandPayCallBack(String data) throws Exception;

    /**
     * 延时分账
     */
    void delayedSplitting(String notifyUrl);

    /**
     * 延时分账异步通知回调
     *
     * @param data 回调参数
     * @return SUCCESS告诉第三方回调成功
     */
    String delayedSplittingCallback(String data);
}
